==> aping-1.3.1.tgz: package/README.md <==
[logo]: http://aping.io/logo/320/aping-logo.png "apiNG"
![apiNG][logo]

[![Join the chat at https://gitter.im/JohnnyTheTank/apiNG](https://img.shields.io/badge/GITTER-join%20chat-green.svg)](https://gitter.im/JohnnyTheTank/apiNG?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![npm version](https://badge.fury.io/js/aping.png)](https://badge.fury.io/js/aping)
[![Bower version](https://badge.fury.io/bo/apiNG.png)](https://badge.fury.io/bo/apiNG)
[![Docs](https://img.shields.io/docs/90%.png)](https://aping.readme.io)

**apiNG** is an AngularJS module that enables you to receive and display data from one or more sources. The data can be aggregated, limited and ordered. The complete setup is dead simple, just by adding data-attributes to your html.

There are two level of usage: _basic_ and _advanced_
* The _basic_ usage is focused on keeping it simple and easy, but with enough power for most use cases
* The _advanced_ usage turns apiNG into a plugin system for data-sources and designs, focused on re-usable modules

## Basic Demos
- [Demo: Random Users (plnkr)](http://plnkr.co/xmflhJ)
- [Demo: Read Json Files (plnkr)](http://plnkr.co/k3DPNc)

## Advanced Demos
- [Social Wall](http://aping.io/#demo) (default design)
- [Image Gallery](https://rawgit.com/JohnnyTheTank/apiNG-design-xgallerify/master/demo/) (images from twitter)
- [Demo: Socal Wall (plnkr)](http://plnkr.co/dz3Dru)
- [ionic + apiNG (plnkr)](http://plnkr.co/edit/WesqTb)

## References
- [sonymusic.de/videos](https://sonymusic.de/videos) (Youtube video playlist & player) based on apiNG
- [olliegabriel.de](http://www.olliegabriel.de/#news) (Facebook News)
- [namikamusik.de](http://www.namikamusik.de/blog/) (Tumblr Blog)

## Documentation
**Full documentation comes up at [aping.readme.io](https://aping.readme.io)**

## Plugins
**apiNG plugin quicklist:** [Youtube](https://github.com/JohnnyTheTank/apiNG-plugin-youtube), [Facebook](https://github.com/JohnnyTheTank/apiNG-plugin-facebook), [Twitter](https://github.com/JohnnyTheTank/apiNG-plugin-codebird), [Instagram](https://github.com/JohnnyTheTank/apiNG-plugin-instagram), [Vimeo](https://github.com/JohnnyTheTank/apiNG-plugin-vimeo), [Flickr](https://github.com/JohnnyTheTank/apiNG-plugin-flickr), [Dailymotion](https://github.com/JohnnyTheTank/apiNG-plugin-dailymotion), [Tumblr](https://github.com/JohnnyTheTank/apiNG-plugin-tumblr), [GitHub](https://github.com/JohnnyTheTank/apiNG-plugin-github), [RSS](https://github.com/JohnnyTheTank/apiNG-plugin-rss), [OpenWeatherMap](https://github.com/JohnnyTheTank/apiNG-plugin-openweathermap), [BandsInTown](https://github.com/JohnnyTheTank/apiNG-plugin-bandsintown)

All apiNG plugins are listed at [aping.readme.io/docs/all-plugins](https://aping.readme.io/docs/all-plugins)

## Designs
All apiNG designs are listed at [aping.readme.io/docs/all-designs](https://aping.readme.io/docs/all-designs)

# License
MIT

==> aping-1.3.2.tgz: package/README.md <==
[logo]: http://johnnythetank.github.io/apiNG/logo/320/aping-logo.png "apiNG"
![apiNG][logo]

[![Join the chat at https://gitter.im/JohnnyTheTank/apiNG](https://img.shields.io/badge/GITTER-join%20chat-green.svg)](https://gitter.im/JohnnyTheTank/apiNG?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![npm version](https://badge.fury.io/js/aping.svg)](https://badge.fury.io/js/aping)
[![Bower version](https://badge.fury.io/bo/apiNG.svg)](https://badge.fury.io/bo/apiNG)
[![Docs](https://img.shields.io/docs/90%.png)](https://aping.readme.io)

**apiNG** is an AngularJS module that enables you to receive and display data from one or more sources. The data can be aggregated, limited and ordered. The complete setup is dead simple, just by adding data-attributes to your html.

There are two level of usage: _basic_ and _advanced_
* The _basic_ usage is focused on keeping it simple and easy, but with enough power for most use cases
* The _advanced_ usage turns apiNG into a plugin system for data-sources and designs, focused on re-usable modules

## Basic Demos
- [Demo: Random Users (plnkr)](http://plnkr.co/xmflhJ)
- [Demo: Read Json Files (plnkr)](http://plnkr.co/k3DPNc)

## Advanced Demos
- [Social Wall](http://johnnythetank.github.io/apiNG//#demo) (default design)
- [Image Gallery](https://rawgit.com/JohnnyTheTank/apiNG-design-xgallerify/master/demo/) (images from twitter)
- [Demo: Socal Wall (plnkr)](http://plnkr.co/dz3Dru)
- ionic + apiNG ([pnklr](http://plnkr.co/edit/WesqTb?p=preview)) ([play.ionic.io](http://play.ionic.io/app/0137f0b5967d))

## References
- [sonymusic.de/videos](https://sonymusic.de/videos) (Youtube video playlist & player) based on apiNG
- [olliegabriel.de](http://www.olliegabriel.de/#news) (Facebook News)
- [namikamusik.de](http://www.namikamusik.de/blog/) (Tumblr Blog)

## Documentation
**Full documentation comes up at [aping.readme.io](https://aping.readme.io)**

## Plugins
**apiNG plugin quicklist:** [Youtube](https://github.com/JohnnyTheTank/apiNG-plugin-youtube), [Facebook](https://github.com/JohnnyTheTank/apiNG-plugin-facebook), [Twitter](https://github.com/JohnnyTheTank/apiNG-plugin-codebird), [Instagram](https://github.com/JohnnyTheTank/apiNG-plugin-instagram), [Vimeo](https://github.com/JohnnyTheTank/apiNG-plugin-vimeo), [Flickr](https://github.com/JohnnyTheTank/apiNG-plugin-flickr), [Dailymotion](https://github.com/JohnnyTheTank/apiNG-plugin-dailymotion), [Tumblr](https://github.com/JohnnyTheTank/apiNG-plugin-tumblr), [GitHub](https://github.com/JohnnyTheTank/apiNG-plugin-github), [RSS](https://github.com/JohnnyTheTank/apiNG-plugin-rss), [OpenWeatherMap](https://github.com/JohnnyTheTank/apiNG-plugin-openweathermap), [BandsInTown](https://github.com/JohnnyTheTank/apiNG-plugin-bandsintown)

All apiNG plugins are listed at [aping.readme.io/docs/all-plugins](https://aping.readme.io/docs/all-plugins)

## Designs
All apiNG designs are listed at [aping.readme.io/docs/all-designs](https://aping.readme.io/docs/all-designs)

# License
MIT
